@@ -13,6 +13,7 @@ from matplotlib import cm
 from matplotlib import colors
 
 import pickle
+from voxelmap.annex import *
 
 
 def load_array(filename):
@@ -33,31 +34,6 @@ def binarize(array,colorindex=1):
     return arrayv
 
     
-def set_axes_radius(ax, origin, radius):
-    '''set_axes_radius and set_axes_equal * * * Credit:
-    Mateen Ulhaq (answered Jun 3 '18 at 7:55)
-    https://stackoverflow.com/questions/13685386/matplotlib-equal-unit-length-with-equal-aspect-ratio-z-axis-is-not-equal-to'''
-    ax.set_xlim3d([origin[0] - radius, origin[0] + radius])
-    ax.set_ylim3d([origin[1] - radius, origin[1] + radius])
-    ax.set_zlim3d([origin[2] - radius, origin[2] + radius])
-def set_axes_equal(ax):
-    '''Make axes of 3D plot have equal scale so that spheres appear as spheres,
-    cubes as cubes, etc..  This is one possible solution to Matplotlib's
-    ax.set_aspect('equal') and ax.axis('equal') not working for 3D.
-    Input
-      ax: a matplotlib axis, e.g., as output from plt.gca().
-    '''
-    limits = np.array([
-        ax.get_xlim3d(),
-        ax.get_ylim3d(),
-        ax.get_zlim3d(),
-    ])
-
-    origin = np.mean(limits, axis=1)
-    radius = 0.5 * np.max(np.abs(limits[:, 1] - limits[:, 0]))
-    set_axes_radius(ax, origin, radius)
-
-
 
 class Model:
 
@@ -76,7 +52,7 @@ class Model:
         self.colormap = cm.cool     # default: cool colormap
         self.alphacm = 1            # default: opaque colormap (alpha=1)
 
-    def customadd(self, key, color, alpha=1):
+    def hashblocksAdd(self, key, color, alpha=1):
         '''Make your own 3-D colormap option. Adds to hashblocks dictionary.
 
         Parameters
@@ -114,8 +90,17 @@ class Model:
     
     def draw(self,coloring='nuclear',figsize=(6.4,4.8)):
         '''Draws voxel model after building it with the provided `array`. 
-        `coloring` option `voxels` requires building custom color map with `Model().customadd`
-        remaining `coloring` options use a default colormap, which may be updated with `Model().gradmap`'''
+        
+        Parameters
+        ----------
+        coloring: string  
+            voxel coloring scheme
+                'nuclear'  colors model radially, from center to exterior
+                'linear'   colors voxel model vertically, top to bottom. 
+                'voxels'   colors voxel model based on the provided keys to its array integers, defined in the `hashblocks` variable from the `Model` class
+        figsize : (float,float)
+            defines plot window dimensions. From matplotlib.pyplot.figure(figsize) kwarg. 
+        '''
 
         Z,X,Y = np.shape(self.array)
 
